@@ -721,7 +721,8 @@ class LocalLogCache:
         dd['dc_time_now'] = tn
         dd['dc_message'] = message
         dd['dc_sev'] = sev
-        self.logs.append(dd)
+        self.logs.insert(0, dd)
+        return
 
 
     def info(self, message):
